@@ -28,7 +28,7 @@ def nanolog(log_type, details, note=None, user=None, ip=None, log_object=None, r
     """
     if not log_type or not details:
         return
-    if not user and request:
+    if not user and request and request.user.is_authenticated():
         user = request.user
     values = dict(
                 user=user,
@@ -36,10 +36,8 @@ def nanolog(log_type, details, note=None, user=None, ip=None, log_object=None, r
                 details=details,
                 note=note,
         )
-    print(ip)
     if not ip and request:
         ip = get_client_ip(request)
-    print(ip)
     try:
         validate_ipv46_address(ip)
         values['ip'] = ip
